==> db4o-5.0-mono.tar.gz: db4o-5.0/src/test/src/com/db4o/test/soda/SodaNumberCoercion.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using com.db4o.query;

namespace com.db4o.test.soda
{
	class SodaNumberCoercion
	{
		class Thing
		{
			public long value;
			
			public Thing(long value)
			{
				this.value = value;
			}
		}
		
		public void store()
		{
			Tester.store(new Thing(10));
			Tester.store(new Thing(100));
			Tester.store(new Thing(42));
		}
		
		public void testIntQueryOnLongField()
		{
			Query q = Tester.query();
			q.constrain(typeof (Thing));
			q.descend("value").constrain(100);
			Tester.ensureEquals(1, q.execute().Count, "testIntQueryOnLongField");
		}
		
	}
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/test/src/com/db4o/test/soda/SodaNumberCoercion.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using com.db4o.query;

namespace com.db4o.test.soda
{
	class SodaNumberCoercion
	{
		class Thing
		{
			public long value;
			
			public Thing(long value)
			{
				this.value = value;
			}
		}
		
		public void Store()
		{
			Tester.Store(new Thing(10));
			Tester.Store(new Thing(100));
			Tester.Store(new Thing(42));
		}
		
		public void TestIntQueryOnLongField()
		{
			Query q = Tester.Query();
			q.Constrain(typeof (Thing));
			q.Descend("value").Constrain(100);
			Tester.EnsureEquals(1, q.Execute().Count, "testIntQueryOnLongField");
		}
		
	}
}
